### Name: fitdist
### Title: Fitting of univariate distributions to non-censored data and
###   goodness-of-fit statistics
### Aliases: fitdist plot.fitdist print.fitdist summary.fitdist
###   fitdistrplus
### Keywords: distribution

### ** Examples


# (1) basic fit of a normal distribution with maximum likelihood estimation
#

x1 <- c(6.4,13.3,4.1,1.3,14.1,10.6,9.9,9.6,15.3,22.1,13.4,
13.2,8.4,6.3,8.9,5.2,10.9,14.4)
f1 <- fitdist(x1,"norm")
print(f1)
plot(f1)
summary(f1)
f1$chisqtable

# (2) use the moment matching estimation
#

f1b <- fitdist(x1,"norm",method="mme",meancount=6)
summary(f1b)
f1b$chisqtable

# (3) MME for log normal distribution
#

f1c <- fitdist(x1,"lnorm",method="mme",meancount=6)
summary(f1c)
f1c$chisqtable

# (4) defining your own distribution functions, here for the Gumbel distribution
# for other distributions, see the CRAN task view dedicated to probability distributions

dgumbel <- function(x,a,b) 1/b*exp((a-x)/b)*exp(-exp((a-x)/b))
pgumbel <- function(q,a,b) exp(-exp((a-q)/b))
qgumbel <- function(p,a,b) a-b*log(-log(p))

f1c <- fitdist(x1,"gumbel",start=list(a=10,b=5))
print(f1c)
plot(f1c)

# (5) fit a discrete distribution (Poisson)
#

x2<-c(rep(4,1),rep(2,3),rep(1,7),rep(0,12))
f2<-fitdist(x2,"pois",chisqbreaks=c(0,1))
plot(f2)
summary(f2)
f2$chisqtable


# (5) comparison of fits of various distributions
#
xw<-rweibull(n=100,shape=2,scale=1)
fa<-fitdist(xw,"weibull")
summary(fa)
fa$chisqtable
fb<-fitdist(xw,"gamma")
summary(fb)
fc<-fitdist(xw,"exp")
summary(fc)

# (6) how to change the optimisation method?
#

fitdist(x1,"gamma",optim.method="Nelder-Mead")
fitdist(x1,"gamma",optim.method="BFGS") 
fitdist(x1,"gamma",optim.method="L-BFGS-B",lower=c(0,0))
fitdist(x1,"gamma",optim.method="SANN")

# (7) custom optimisation function
#

#create the sample
mysample <- rexp(100, 5)
mystart <- 8

res1 <- fitdist(mysample, dexp, start= mystart, optim.method="Nelder-Mead")

#show the result
summary(res1)

#the warning tell us to use optimise, because the Nelder-Mead is not adequate.

#to meet the standard 'fn' argument and specific name arguments, we wrap optimize,
myoptimize <- function(fn, par, ...) 
{
    res <- optimize(f=fn, ..., maximum=FALSE)  #assume the optimization function minimize
    
    standardres <- c(res, convergence=0, value=res$objective, par=res$minimum, hessian=NA)
    
    return(standardres)
}

#call fitdist with a 'custom' optimization function
res2 <- fitdist(mysample, dexp, start=mystart, custom.optim=myoptimize, interval=c(0, 100))

#show the result
summary(res2)

# (8) custom optimisation function - another example with the genetic algorithm
#
## Not run: 
##D     #set a sample
##D     x1 <- c(6.4, 13.3, 4.1, 1.3, 14.1, 10.6, 9.9, 9.6, 15.3, 22.1, 13.4, 13.2, 8.4, 6.3, 8.9, 5.2, 10.9, 14.4) 
##D     fit1 <- fitdist(x1, "gamma")
##D     summary(fit1)
##D 
##D     #wrap genoud function rgenoud package
##D     mygenoud <- function(fn, par, ...) 
##D     {
##D         require(rgenoud)
##D         res <- genoud(fn, starting.values=par, ...)        
##D         standardres <- c(res, convergence=0)
##D             
##D         return(standardres)
##D     }
##D 
##D     #call fitdist with a 'custom' optimization function
##D     fit2 <- fitdist(x1, "gamma", custom.optim=mygenoud, nvars=2,    
##D         Domains=cbind(c(0,0), c(10, 10)), boundary.enforcement=1, 
##D         print.level=1, hessian=TRUE)
##D 
##D     summary(fit2)
## End(Not run)




